@@ -32,9 +32,9 @@ def set_default_settings(user_manager, app_config):
     um.password_salt            = sd('USER_PASSWORD_SALT',              app_config['SECRET_KEY'])
     um.reset_password_expiration= sd('USER_RESET_PASSWORD_EXPIRATION',  2*24*3600)   # 2 days
     um.require_invitation       = sd('USER_REQUIRE_INVITATION',         False)
-    um.send_password_changed_email = sd('USER_SEND_REGISTERED_EMAIL',   True)
-    um.send_registered_email       = sd('USER_SEND_REGISTERED_EMAIL',   True)
-    um.send_username_changed_email = sd('USER_SEND_REGISTERED_EMAIL',   True)
+    um.send_password_changed_email = sd('USER_SEND_PASSWORD_CHANGED_EMAIL',   True)
+    um.send_registered_email       = sd('USER_SEND_REGISTERED_EMAIL',         True)
+    um.send_username_changed_email = sd('USER_SEND_USERNAME_CHANGED_EMAIL',   True)
     # Set default URLs
     um.change_password_url      = sd('USER_CHANGE_PASSWORD_URL',        '/user/change-password')
     um.change_username_url      = sd('USER_CHANGE_USERNAME_URL',        '/user/change-username')
